--- loncom/publisher/lonpubdir.pm 2012/10/29 17:38:55 1.144
+++ loncom/publisher/lonpubdir.pm 2014/03/11 01:16:49 1.150
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
# Construction Space Directory Lister
#
-# $Id: lonpubdir.pm,v 1.144 2012/10/29 17:38:55 raeburn Exp $
+# $Id: lonpubdir.pm,v 1.150 2014/03/11 01:16:49 musolffc Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -46,7 +46,7 @@ sub handler {
my $r=shift;
- # Validate access to the construction space and get username@domain.
+ # Validate access to the construction space and get username:domain.
my $uname;
my $udom;
@@ -79,15 +79,23 @@ sub handler {
my $numdir = 0;
my $numres = 0;
+ # Retrieving value for sortby from QUERY_STRING
+ &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['sortby']);
+
+ # Default sort by 'Name'
+ if (! exists($env{'form.sortby'})) {
+ $env{'form.sortby'} = 'filename';
+ }
+
# Start off the directory table.
$r->print(&Apache::loncommon::start_data_table()
.&Apache::loncommon::start_data_table_header_row()
.'
'.&mt('Type').' | '
.''.&mt('Actions').' | '
- .''.&mt('Name').' | '
+ .'Name ▼ | '
.''.&mt('Title').' | '
.''.&mt('Status').' | '
- .''.&mt('Last Modified').' | '
+ .'Last Modified ▼ | '
.&Apache::loncommon::end_data_table_header_row()
);
@@ -95,24 +103,51 @@ sub handler {
my $dirptr=16384; # Mask indicating a directory in stat.cmode.
opendir(DIR,$fn);
+ my $filehash = {};
+ my $sortby = $env{'form.sortby'};
my @files=sort {uc($a) cmp uc($b)} (readdir(DIR));
foreach my $filename (@files) {
- my ($cdev,$cino,$cmode,$cnlink,
- $cuid,$cgid,$crdev,$csize,
- $catime,$cmtime,$cctime,
- $cblksize,$cblocks)=stat($fn.'/'.$filename);
-
- my $extension='';
- if ($filename=~/\.(\w+)$/) { $extension=$1; }
- if ($cmode&$dirptr) {
- &putdirectory($r, $thisdisfn, $linkdir, $filename, $cmtime,$targetdir,\%bombs,\$numdir);
- } elsif (&Apache::loncommon::fileembstyle($extension) ne 'hdn') {
- &putresource($r, $udom, $uname, $filename, $thisdisfn, $resdir,
- $targetdir, $linkdir, $cmtime,\%bombs,\$numres);
- } else {
- # "hidden" extension and not a directory, so hide it away.
+ next if ($filename eq '.DS_Store');
+ my ($cmode,$cmtime)=(stat($fn.'/'.$filename))[2,9];
+ # If you want to sort by "last modified", we need to make this hash.
+ if ($sortby eq 'cmtime') {
+ $filehash->{ $filename } = {"cmtime" => $cmtime,};
}
- }
+ # Otherwise sort by name. Don't bother with filehash. Continue printing contents.
+ else {
+ my $extension='';
+ if ($filename=~/\.(\w+)$/) { $extension=$1; }
+ if ($cmode&$dirptr) {
+ &putdirectory($r, $thisdisfn, $linkdir, $filename, $cmtime,$targetdir,\%bombs,\$numdir);
+ } elsif (&Apache::loncommon::fileembstyle($extension) ne 'hdn') {
+ &putresource($r, $udom, $uname, $filename, $thisdisfn, $resdir,
+ $targetdir, $linkdir, $cmtime,\%bombs,\$numres);
+ } else {
+ # "hidden" extension and not a directory, so hide it away.
+ }
+ }
+ };
+
+ # Sorting files by "last modified" if that's what you selected
+ if ($sortby eq 'cmtime') {
+ my @sorted_files = sort {
+ $filehash->{$b}->{$sortby} <=> $filehash->{$a}->{$sortby}
+ } (keys(%{$filehash}));
+ foreach my $filename (@sorted_files) {
+ my ($cmode,$cmtime)=(stat($fn.'/'.$filename))[2,9];
+ my $extension='';
+ if ($filename=~/\.(\w+)$/) { $extension=$1; }
+ if ($cmode&$dirptr) {
+ &putdirectory($r, $thisdisfn, $linkdir, $filename, $cmtime,$targetdir,\%bombs,\$numdir);
+ } elsif (&Apache::loncommon::fileembstyle($extension) ne 'hdn') {
+ &putresource($r, $udom, $uname, $filename, $thisdisfn, $resdir,
+ $targetdir, $linkdir, $cmtime,\%bombs,\$numres);
+ } else {
+ # "hidden" extension and not a directory, so hide it away.
+ };
+ };
+ };
+
closedir(DIR);
$r->print(&Apache::loncommon::end_data_table()
@@ -143,20 +178,28 @@ sub startpage {
&Apache::lonhtmlcommon::clear_breadcrumbs();
&Apache::lonhtmlcommon::add_breadcrumb({
- 'text' => 'Construction Space',
+ 'text' => 'Authoring Space',
'href' => &Apache::loncommon::authorspace($formaction),
});
# breadcrumbs (and tools) will be created
# in start_page->bodytag->innerregister
$env{'request.noversionuri'}=$formaction;
- $r->print(&Apache::loncommon::start_page('Construction Space',undef));
+ $r->print(&Apache::loncommon::start_page('Authoring Space',undef));
+
+ my $londocroot = $Apache::lonnet::perlvar{'lonDocRoot'};
+ my $current_disk_usage = &Apache::lonnet::diskusage($udom,$uname,"$londocroot/priv/$udom/$uname");
+ my $disk_quota = &Apache::loncommon::get_user_quota($uname,$udom,'author'); #expressed in Mb
+ $disk_quota = 1000 * $disk_quota; # convert from Mb to kb
$r->print(&Apache::loncommon::head_subbox(
- &Apache::loncommon::CSTR_pageheader()));
+ ''
+ .&Apache::lonhtmlcommon::display_usage($current_disk_usage,$disk_quota)
+ .'
'
+ .&Apache::loncommon::CSTR_pageheader()));
my $esc_thisdisfn = &Apache::loncommon::escape_single($thisdisfn);
- my $doctitle = 'LON-CAPA '.&mt('Construction Space');
+ my $doctitle = 'LON-CAPA '.&mt('Authoring Space');
my $newname = &mt('New Name');
my $pubdirscript=(<
@@ -616,11 +659,11 @@ sub putresource {
my $editlink='';
my $editlink2='';
if ($filename=~/\.(xml|html|htm|xhtml|xhtm|sty)$/) {
- $editlink='
('.&mt('Edit').')';
+ $editlink='
('.&mt('Edit').')';
}
if ($filename=~/$LONCAPA::assess_re/) {
- $editlink=' ('.&mt('EditXML').')';
- $editlink2='
('.&mt('Edit').')';
+ $editlink=' ('.&mt('EditXML').')';
+ $editlink2='
('.&mt('Edit').')';
}
if ($filename=~/\.(problem|exam|quiz|assess|survey|form|library|xml|html|htm|xhtml|xhtm|sty)$/) {
$editlink.=' ('.&mt('Clean Up').')';
@@ -706,7 +749,7 @@ __END__
=head1 NAME
-Apache::lonpubdir - Construction space directory lister
+Apache::lonpubdir - Authoring space directory lister
=head1 SYNOPSIS
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
-# Construction Space Directory Lister
+# Authoring Space Directory Lister
#